@@ -20,7 +20,7 @@
 
 template <typename eT>
 inline diagview<eT>::~diagview() {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 }
 
 template <typename eT>
@@ -31,7 +31,7 @@ arma_inline diagview<eT>::diagview(const Mat<eT>& in_m, const uword in_row_offse
       col_offset(in_col_offset),
       n_rows(in_len),
       n_elem(in_len) {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 }
 
 template <typename eT>
@@ -41,7 +41,7 @@ inline diagview<eT>::diagview(const diagview<eT>& in)
       col_offset(in.col_offset),
       n_rows(in.n_rows),
       n_elem(in.n_elem) {
-  arma_extra_debug_sigprint(arma_str::format("this = %x   in = %x") % this % &in);
+  arma_debug_sigprint(arma_str::format("this: %x; in: %x") % this % &in);
 }
 
 template <typename eT>
@@ -51,7 +51,7 @@ inline diagview<eT>::diagview(diagview<eT>&& in)
       col_offset(in.col_offset),
       n_rows(in.n_rows),
       n_elem(in.n_elem) {
-  arma_extra_debug_sigprint(arma_str::format("this = %x   in = %x") % this % &in);
+  arma_debug_sigprint(arma_str::format("this: %x; in: %x") % this % &in);
 
   // for paranoia
 
@@ -64,12 +64,12 @@ inline diagview<eT>::diagview(diagview<eT>&& in)
 //! set a diagonal of our matrix using a diagonal from a foreign matrix
 template <typename eT>
 inline void diagview<eT>::operator=(const diagview<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   diagview<eT>& d = *this;
 
-  arma_debug_check((d.n_elem != x.n_elem),
-                   "diagview: diagonals have incompatible lengths");
+  arma_conform_check((d.n_elem != x.n_elem),
+                     "diagview: diagonals have incompatible lengths");
 
   Mat<eT>& d_m = const_cast<Mat<eT>&>(d.m);
   const Mat<eT>& x_m = x.m;
@@ -104,7 +104,7 @@ inline void diagview<eT>::operator=(const diagview<eT>& x) {
 
 template <typename eT>
 inline void diagview<eT>::operator+=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& t_m = const_cast<Mat<eT>&>(m);
 
@@ -119,7 +119,7 @@ inline void diagview<eT>::operator+=(const eT val) {
 
 template <typename eT>
 inline void diagview<eT>::operator-=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& t_m = const_cast<Mat<eT>&>(m);
 
@@ -134,7 +134,7 @@ inline void diagview<eT>::operator-=(const eT val) {
 
 template <typename eT>
 inline void diagview<eT>::operator*=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& t_m = const_cast<Mat<eT>&>(m);
 
@@ -149,7 +149,7 @@ inline void diagview<eT>::operator*=(const eT val) {
 
 template <typename eT>
 inline void diagview<eT>::operator/=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& t_m = const_cast<Mat<eT>&>(m);
 
@@ -166,7 +166,7 @@ inline void diagview<eT>::operator/=(const eT val) {
 template <typename eT>
 template <typename T1>
 inline void diagview<eT>::operator=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   diagview<eT>& d = *this;
 
@@ -178,19 +178,19 @@ inline void diagview<eT>::operator=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "diagview: given object has incompatible size");
 
-  const bool is_alias = P.is_alias(d_m);
+  const bool have_alias = P.is_alias(d_m);
 
-  if (is_alias) {
-    arma_extra_debug_print("aliasing detected");
+  if (have_alias) {
+    arma_debug_print("aliasing detected");
   }
 
   if ((is_Mat<typename Proxy<T1>::stored_type>::value) || (Proxy<T1>::use_at) ||
-      (is_alias)) {
-    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, is_alias);
+      (have_alias)) {
+    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, have_alias);
     const Mat<eT>& x = tmp.M;
 
     const eT* x_mem = x.memptr();
@@ -228,7 +228,7 @@ inline void diagview<eT>::operator=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void diagview<eT>::operator+=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   diagview<eT>& d = *this;
 
@@ -240,19 +240,19 @@ inline void diagview<eT>::operator+=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "diagview: given object has incompatible size");
 
-  const bool is_alias = P.is_alias(d_m);
+  const bool have_alias = P.is_alias(d_m);
 
-  if (is_alias) {
-    arma_extra_debug_print("aliasing detected");
+  if (have_alias) {
+    arma_debug_print("aliasing detected");
   }
 
   if ((is_Mat<typename Proxy<T1>::stored_type>::value) || (Proxy<T1>::use_at) ||
-      (is_alias)) {
-    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, is_alias);
+      (have_alias)) {
+    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, have_alias);
     const Mat<eT>& x = tmp.M;
 
     const eT* x_mem = x.memptr();
@@ -290,7 +290,7 @@ inline void diagview<eT>::operator+=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void diagview<eT>::operator-=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   diagview<eT>& d = *this;
 
@@ -302,19 +302,19 @@ inline void diagview<eT>::operator-=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "diagview: given object has incompatible size");
 
-  const bool is_alias = P.is_alias(d_m);
+  const bool have_alias = P.is_alias(d_m);
 
-  if (is_alias) {
-    arma_extra_debug_print("aliasing detected");
+  if (have_alias) {
+    arma_debug_print("aliasing detected");
   }
 
   if ((is_Mat<typename Proxy<T1>::stored_type>::value) || (Proxy<T1>::use_at) ||
-      (is_alias)) {
-    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, is_alias);
+      (have_alias)) {
+    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, have_alias);
     const Mat<eT>& x = tmp.M;
 
     const eT* x_mem = x.memptr();
@@ -352,7 +352,7 @@ inline void diagview<eT>::operator-=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void diagview<eT>::operator%=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   diagview<eT>& d = *this;
 
@@ -364,19 +364,19 @@ inline void diagview<eT>::operator%=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "diagview: given object has incompatible size");
 
-  const bool is_alias = P.is_alias(d_m);
+  const bool have_alias = P.is_alias(d_m);
 
-  if (is_alias) {
-    arma_extra_debug_print("aliasing detected");
+  if (have_alias) {
+    arma_debug_print("aliasing detected");
   }
 
   if ((is_Mat<typename Proxy<T1>::stored_type>::value) || (Proxy<T1>::use_at) ||
-      (is_alias)) {
-    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, is_alias);
+      (have_alias)) {
+    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, have_alias);
     const Mat<eT>& x = tmp.M;
 
     const eT* x_mem = x.memptr();
@@ -414,7 +414,7 @@ inline void diagview<eT>::operator%=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void diagview<eT>::operator/=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   diagview<eT>& d = *this;
 
@@ -426,19 +426,19 @@ inline void diagview<eT>::operator/=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "diagview: given object has incompatible size");
 
-  const bool is_alias = P.is_alias(d_m);
+  const bool have_alias = P.is_alias(d_m);
 
-  if (is_alias) {
-    arma_extra_debug_print("aliasing detected");
+  if (have_alias) {
+    arma_debug_print("aliasing detected");
   }
 
   if ((is_Mat<typename Proxy<T1>::stored_type>::value) || (Proxy<T1>::use_at) ||
-      (is_alias)) {
-    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, is_alias);
+      (have_alias)) {
+    const unwrap_check<typename Proxy<T1>::stored_type> tmp(P.Q, have_alias);
     const Mat<eT>& x = tmp.M;
 
     const eT* x_mem = x.memptr();
@@ -476,7 +476,7 @@ inline void diagview<eT>::operator/=(const Base<eT, T1>& o) {
 //! extract a diagonal and store it as a column vector
 template <typename eT>
 inline void diagview<eT>::extract(Mat<eT>& out, const diagview<eT>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // NOTE: we're assuming that the matrix has already been set to the correct size and
   // there is no aliasing; size setting and alias checking is done by either the Mat
@@ -507,9 +507,9 @@ inline void diagview<eT>::extract(Mat<eT>& out, const diagview<eT>& in) {
 //! X += Y.diag()
 template <typename eT>
 inline void diagview<eT>::plus_inplace(Mat<eT>& out, const diagview<eT>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols, "addition");
+  arma_conform_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols, "addition");
 
   const Mat<eT>& in_m = in.m;
 
@@ -536,10 +536,10 @@ inline void diagview<eT>::plus_inplace(Mat<eT>& out, const diagview<eT>& in) {
 //! X -= Y.diag()
 template <typename eT>
 inline void diagview<eT>::minus_inplace(Mat<eT>& out, const diagview<eT>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols,
-                              "subtraction");
+  arma_conform_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols,
+                                "subtraction");
 
   const Mat<eT>& in_m = in.m;
 
@@ -566,10 +566,10 @@ inline void diagview<eT>::minus_inplace(Mat<eT>& out, const diagview<eT>& in) {
 //! X %= Y.diag()
 template <typename eT>
 inline void diagview<eT>::schur_inplace(Mat<eT>& out, const diagview<eT>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols,
-                              "element-wise multiplication");
+  arma_conform_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols,
+                                "element-wise multiplication");
 
   const Mat<eT>& in_m = in.m;
 
@@ -596,10 +596,10 @@ inline void diagview<eT>::schur_inplace(Mat<eT>& out, const diagview<eT>& in) {
 //! X /= Y.diag()
 template <typename eT>
 inline void diagview<eT>::div_inplace(Mat<eT>& out, const diagview<eT>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols,
-                              "element-wise division");
+  arma_conform_assert_same_size(out.n_rows, out.n_cols, in.n_rows, in.n_cols,
+                                "element-wise division");
 
   const Mat<eT>& in_m = in.m;
 
@@ -650,14 +650,14 @@ arma_inline eT diagview<eT>::at(const uword ii) const {
 
 template <typename eT>
 arma_inline eT& diagview<eT>::operator()(const uword ii) {
-  arma_debug_check_bounds((ii >= n_elem), "diagview::operator(): out of bounds");
+  arma_conform_check_bounds((ii >= n_elem), "diagview::operator(): out of bounds");
 
   return (const_cast<Mat<eT>&>(m)).at(ii + row_offset, ii + col_offset);
 }
 
 template <typename eT>
 arma_inline eT diagview<eT>::operator()(const uword ii) const {
-  arma_debug_check_bounds((ii >= n_elem), "diagview::operator(): out of bounds");
+  arma_conform_check_bounds((ii >= n_elem), "diagview::operator(): out of bounds");
 
   return m.at(ii + row_offset, ii + col_offset);
 }
@@ -674,23 +674,23 @@ arma_inline eT diagview<eT>::at(const uword row, const uword) const {
 
 template <typename eT>
 arma_inline eT& diagview<eT>::operator()(const uword row, const uword col) {
-  arma_debug_check_bounds(((row >= n_elem) || (col > 0)),
-                          "diagview::operator(): out of bounds");
+  arma_conform_check_bounds(((row >= n_elem) || (col > 0)),
+                            "diagview::operator(): out of bounds");
 
   return (const_cast<Mat<eT>&>(m)).at(row + row_offset, row + col_offset);
 }
 
 template <typename eT>
 arma_inline eT diagview<eT>::operator()(const uword row, const uword col) const {
-  arma_debug_check_bounds(((row >= n_elem) || (col > 0)),
-                          "diagview::operator(): out of bounds");
+  arma_conform_check_bounds(((row >= n_elem) || (col > 0)),
+                            "diagview::operator(): out of bounds");
 
   return m.at(row + row_offset, row + col_offset);
 }
 
 template <typename eT>
 inline void diagview<eT>::replace(const eT old_val, const eT new_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& x = const_cast<Mat<eT>&>(m);
 
@@ -713,7 +713,7 @@ inline void diagview<eT>::replace(const eT old_val, const eT new_val) {
 
 template <typename eT>
 inline void diagview<eT>::clean(const typename get_pod_type<eT>::result threshold) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp(*this);
 
@@ -724,7 +724,7 @@ inline void diagview<eT>::clean(const typename get_pod_type<eT>::result threshol
 
 template <typename eT>
 inline void diagview<eT>::clamp(const eT min_val, const eT max_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp(*this);
 
@@ -735,7 +735,7 @@ inline void diagview<eT>::clamp(const eT min_val, const eT max_val) {
 
 template <typename eT>
 inline void diagview<eT>::fill(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& x = const_cast<Mat<eT>&>(m);
 
@@ -748,21 +748,21 @@ inline void diagview<eT>::fill(const eT val) {
 
 template <typename eT>
 inline void diagview<eT>::zeros() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   (*this).fill(eT(0));
 }
 
 template <typename eT>
 inline void diagview<eT>::ones() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   (*this).fill(eT(1));
 }
 
 template <typename eT>
 inline void diagview<eT>::randu() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& x = const_cast<Mat<eT>&>(m);
 
@@ -775,7 +775,7 @@ inline void diagview<eT>::randu() {
 
 template <typename eT>
 inline void diagview<eT>::randn() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT>& x = const_cast<Mat<eT>&>(m);
 
@@ -786,4 +786,12 @@ inline void diagview<eT>::randn() {
   }
 }
 
+template <typename eT>
+template <typename eT2>
+inline bool diagview<eT>::is_alias(const Mat<eT2>& X) const {
+  arma_debug_sigprint();
+
+  return m.is_alias(X);
+}
+
 //! @}
